# OperationJobType

The operation type of the job.

## Enum

* `DELETE` (value: `'Delete'`)

* `CANCEL` (value: `'Cancel'`)

* `POST` (value: `'Post'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


